@@ -1,5 +1,7 @@
 #include "info_comics_view.h"
 
+#include "yacreader_global.h"
+
 #include <QtQuick>
 #include <QQuickWidget>
 
@@ -21,7 +23,7 @@ InfoComicsView::InfoComicsView(QWidget *parent)
     QQmlContext *ctxt = view->rootContext();
 
     LibraryUITheme theme;
-#ifdef Q_OS_MAC
+#ifdef Y_MAC_UI
     theme = Light;
 #else
     theme = Dark;
@@ -44,6 +46,8 @@ InfoComicsView::InfoComicsView(QWidget *parent)
 
         ctxt->setContextProperty("readTickUncheckedColor", "#DEDEDE");
         ctxt->setContextProperty("readTickCheckedColor", "#E84852");
+
+        ctxt->setContextProperty("showDropShadow", QVariant(false));
     } else {
         ctxt->setContextProperty("infoBackgroundColor", "#2E2E2E");
         ctxt->setContextProperty("topShadow", "info-top-shadow.png");
@@ -61,6 +65,8 @@ InfoComicsView::InfoComicsView(QWidget *parent)
 
         ctxt->setContextProperty("readTickUncheckedColor", "#1C1C1C");
         ctxt->setContextProperty("readTickCheckedColor", "#E84852");
+
+        ctxt->setContextProperty("showDropShadow", QVariant(true));
     }
 
     ctxt->setContextProperty("backgroundImage", QUrl());
