@@ -8,7 +8,10 @@
 #include <QVariant>
 #include <QDateTime>
 
-SessionController::SessionController() {}
+using stefanfrings::HttpRequest;
+using stefanfrings::HttpResponse;
+
+SessionController::SessionController() { }
 
 void SessionController::service(HttpRequest &request, HttpResponse &response)
 {
