@@ -13,13 +13,13 @@ class ServerConfigDialog : public QDialog
     Q_OBJECT
 public:
     ServerConfigDialog(QWidget *parent = 0);
+    void showEvent(QShowEvent *event) override;
 
 private:
     QComboBox *ip;
     QLineEdit *port;
 
     QCheckBox *check;
-    QCheckBox *performanceWorkaroundCheck;
 
     QPushButton *close;
     QPushButton *accept;
@@ -30,7 +30,6 @@ public slots:
     void generateQR(const QString &serverAddress);
     void regenerateQR(const QString &ip);
     void enableServer(int status);
-    void enableperformanceWorkaround(int status);
     void updatePort();
 signals:
     void portChanged(QString port);
