@@ -1,3 +1,9 @@
+
+#include <QtGlobal>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#undef __OBJC_BOOL_IS_BOOL
+#endif
+
 #import <AppKit/AppKit.h>
 #include "trayhandler.h"
 
@@ -8,4 +14,4 @@ void OSXShowDockIcon()
 void OSXHideDockIcon()
 {
     [NSApp setActivationPolicy:NSApplicationActivationPolicyAccessory];
-}
\ No newline at end of file
+}
