@@ -1,5 +1,7 @@
 #include "check_new_version.h"
 
+#include "yacreader_global.h"
+
 #include <QUrl>
 #include <QtGlobal>
 #include <QStringList>
@@ -9,13 +11,14 @@
 #include <QTimer>
 #include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QRegExp>
 
 #define PREVIOUS_VERSION_TESTING "6.0.0"
 
 HttpVersionChecker::HttpVersionChecker()
-    : HttpWorker("https://raw.githubusercontent.com/YACReader/yacreader/master/common/yacreader_global.h")
+    : HttpWorker("https://raw.githubusercontent.com/YACReader/yacreader/master/common/yacreader_global.h", DEFAULT_USER_AGENT)
 {
-    connect(this, SIGNAL(dataReady(const QByteArray &)), this, SLOT(checkNewVersion(const QByteArray &)));
+    connect(this, &HttpVersionChecker::dataReady, this, QOverload<const QByteArray &>::of(&HttpVersionChecker::checkNewVersion));
 }
 
 void HttpVersionChecker::checkNewVersion(const QByteArray &data)
@@ -27,17 +30,16 @@ bool HttpVersionChecker::checkNewVersion(QString sourceContent)
 {
     QRegExp rx("#define VERSION \"([0-9]+).([0-9]+).([0-9]+)\"");
 
-    int index = 0;
     bool newVersion = false;
     bool sameVersion = true;
-    //bool currentVersionIsNewer = false;
+    // bool currentVersionIsNewer = false;
 #ifdef QT_DEBUG
     QString version(PREVIOUS_VERSION_TESTING);
 #else
     QString version(VERSION);
 #endif
     QStringList sl = version.split(".");
-    if ((index = rx.indexIn(sourceContent)) != -1) {
+    if (rx.indexIn(sourceContent) != -1) {
         int length = qMin(sl.size(), (rx.cap(4) != "") ? 4 : 3);
         for (int i = 0; i < length; i++) {
             if (rx.cap(i + 1).toInt() < sl.at(i).toInt()) {
