@@ -1,40 +1,48 @@
 #include "scroll_management.h"
+#include <QtCore>
+#include <QApplication>
 
 ScrollManagement::ScrollManagement()
 {
-    wheelTimer = new QTime();
+    wheelTimer = new QElapsedTimer();
     wheelTimer->start();
     wheelAccumulator = 0;
 }
 
 ScrollManagement::Movement ScrollManagement::getMovement(QWheelEvent *event)
 {
-    /*QLOG_DEBUG() << "WheelEvent angle delta : " << event->angleDelta();
-    QLOG_DEBUG() << "WheelEvent pixel delta : " << event->pixelDelta();*/
+    //    qDebug() << "WheelEvent angle delta : " << event->angleDelta();
+    //    qDebug() << "WheelEvent pixel delta : " << event->pixelDelta();
+    //    qDebug() << "Accumulator : " << wheelAccumulator;
 
+    int delta;
     int tooFast = 1;
     int timeThrottle = 16;
-    int minimumMove = 70;
+    int minimumMove;
 
-    //avoid any events overflood
+    if (event->pixelDelta().x() != 0 || event->pixelDelta().y() != 0) {
+        delta = event->pixelDelta().y() + event->pixelDelta().x();
+        minimumMove = 30;
+    } else {
+        delta = (event->angleDelta().y() / 8) + (event->angleDelta().x() / 8);
+        minimumMove = 8;
+    }
+
+    wheelAccumulator += delta;
+
+    // avoid any events overflood
     if ((wheelTimer->elapsed() < tooFast)) {
         event->setAccepted(true);
         return None;
     }
 
-    // Accumulate the delta
-    if ((event->delta() < 0) != (wheelAccumulator < 0)) //different sign means change in direction
-        wheelAccumulator = 0;
-
-    wheelAccumulator += event->delta();
-
-    //Do not process events too fast
+    // Do not process events too fast
     if ((wheelTimer->elapsed() < timeThrottle)) {
         event->setAccepted(true);
         return None;
     }
 
-    //small intervals are ignored until with have enough acumulated delta
+    // small intervals are ignored until with have enough acumulated delta
     if ((wheelAccumulator < minimumMove) && (wheelAccumulator > -minimumMove)) {
         event->setAccepted(true);
         return None;
@@ -47,7 +55,7 @@ ScrollManagement::Movement ScrollManagement::getMovement(QWheelEvent *event)
         m = Backward;
 
     event->accept();
-    //Clean up
+    // Clean up
     wheelAccumulator = 0;
     wheelTimer->restart();
 
